Crate base_traits

Traits

  • Trait defining instance method as_f64() : f64 that provides a cost-free conversion into f64.
  • Trait defining instance method as_isize() : isize that provides a cost-free conversion into isize.
  • Trait defining instance method as_str() : &str that allows a type to expose its contiguous character representation to client code.
  • Trait defining instance method as_usize() : usize that provides a cost-free conversion into usize.
  • Trait defining class method infinity() : T that creates an instance of the implementing type that is conceptually (or actually) infinity.
  • Trait defining instance method is_default() : bool that allows a type instance to indicate whether it holds the “default” value.
  • Trait defining instance method is_empty() : bool that indicates whether the implementing type instance is logically empty.
  • Trait defining instance method is_infinity() : bool that indicates whether the implementing type instance is conceptually (or actually) infinite.
  • Trait defining instance method is_nan() : bool that indicates whether the implementing type instance has a value that is deemed to be “not a number” (as in so for f32::NAN f64::NAN).
  • Trait defining instance method is_zero() : bool that indicates whether the implementing type instance is numerically zero.
  • Trait defining instance method len() : usize that indicates whether the implementing type instance is logically empty.
  • Trait defining instance method to_f64() : f64 that provides a potentially expensive conversion into f64.
  • Trait defining instance method to_isize() : isize that provides a potentially expensive conversion into isize.
  • Trait defining instance method to_usize() : usize that provides a potentially expensive conversion into usize.
  • Trait defining class method zero() : T that creates an instance of the implementing type that is conceptually (or actually) zero.