AsF64

Trait AsF64 

pub trait AsF64 {
    // Required method
    fn as_f64(&self) -> f64;
}
Trait defining instance method as_f64() : f64 that provides a cost-free conversion into f64.

It is expected that the implementing type “is-a” f64 in a direct manner as well as in a logical manner.

Additional Implementations on Foreign Types

Built-in Types

If the feature "implement-AsF64-for-built_ins" is defined (as it is by "default"), then this is also implemented for the following type(s):

Required Methods

fn as_f64(&self) -> f64

Implementations on Foreign Types

Source

impl AsF64 for &f64

Source

fn as_f64(&self) -> f64

Source

impl AsF64 for f64

Source

fn as_f64(&self) -> f64

Source

impl<T: AsF64 + ?Sized> AsF64 for Box<T>

Available on non-crate feature nostd only.
Source

fn as_f64(&self) -> f64

Source

impl<T: AsF64 + ?Sized> AsF64 for Rc<T>

Available on non-crate feature nostd only.
Source

fn as_f64(&self) -> f64

Implementors