AsI32

Trait AsI32 

pub trait AsI32 {
    // Required method
    fn as_i32(&self) -> i32;
}
Trait defining instance method as_i32() : i32 that provides a cost-free conversion into i32.

It is expected that the implementing type “is-a” i32 in a direct manner as well as in a logical manner.

Additional Implementations on Foreign Types

Built-in Types

If the feature "implement-AsI32-for-built_ins" is defined (as it is by "default"), then this is also implemented for the following type(s):

Required Methods

fn as_i32(&self) -> i32

Implementations on Foreign Types

Source

impl AsI32 for i32

Source

fn as_i32(&self) -> i32

Implementors