AsI64

Trait AsI64 

pub trait AsI64 {
    // Required method
    fn as_i64(&self) -> i64;
}
Trait defining instance method as_i64() : i64 that provides a cost-free conversion into i64.

It is expected that the implementing type “is-a” i64 in a direct manner as well as in a logical manner.

Additional Implementations on Foreign Types

Built-in Types

If the feature "implement-AsI64-for-built_ins" is defined (as it is by "default"), then this is also implemented for the following type(s):

Required Methods

fn as_i64(&self) -> i64

Implementations on Foreign Types

Source

impl AsI64 for i64

Source

fn as_i64(&self) -> i64

Implementors