AsU32

Trait AsU32 

pub trait AsU32 {
    // Required method
    fn as_u32(&self) -> u32;
}
Trait defining instance method as_u32() : u32 that provides a cost-free conversion into u32.

It is expected that the implementing type “is-a” u32 in a direct manner as well as in a logical manner.

Additional Implementations on Foreign Types

Built-in Types

If the feature "implement-AsU32-for-built_ins" is defined (as it is by "default"), then this is also implemented for the following type(s):

Required Methods

fn as_u32(&self) -> u32

Implementations on Foreign Types

Source

impl AsU32 for u32

Source

fn as_u32(&self) -> u32

Implementors