AsU64

Trait AsU64 

pub trait AsU64 {
    // Required method
    fn as_u64(&self) -> u64;
}
Trait defining instance method as_u64() : u64 that provides a cost-free conversion into u64.

It is expected that the implementing type “is-a” u64 in a direct manner as well as in a logical manner.

Additional Implementations on Foreign Types

Built-in Types

If the feature "implement-AsU64-for-built_ins" is defined (as it is by "default"), then this is also implemented for the following type(s):

Required Methods

fn as_u64(&self) -> u64

Implementations on Foreign Types

Source

impl AsU64 for u64

Source

fn as_u64(&self) -> u64

Implementors