IsEmpty

Trait IsEmpty 

pub trait IsEmpty {
    // Required method
    fn is_empty(&self) -> bool;
}
Trait defining instance method is_empty() : bool that indicates whether the implementing type instance is logically empty.

Additional Implementations on Foreign Types

Built-in Types

If the feature "implement-IsEmpty-for-built_ins" is defined (as it is by "default"), then this is also implemented for the following types:

  • str;
  • [T; N];
  • [T];

Standard Collection Types

If the feature "implement-IsEmpty-for-standard_collection_types" is defined (as it is by "default"), then this is also implemented for the following types:

Standard FFI Types

If the feature "implement-IsEmpty-for-standard_ffi_types" is defined (as it is by "default"), then this is also implemented for the following types:

Standard Path Types

If the feature "implement-IsEmpty-for-standard_path_types" is defined (as it is by "default"), then this is also implemented for the following types:

Standard Process Types

If the feature "implement-IsEmpty-for-standard_process_types" is defined (as it is by "default"), then this is also implemented for the following types:

Standard Range Types

If the feature "implement-IsEmpty-for-standard_range_types" is defined (as it is by "default"), then this is also implemented for the following types:

Standard Time Types

If the feature "implement-IsEmpty-for-standard_time_types" is defined (which is NOT by "default"), then this is also implemented for the following types:

Required Methods

fn is_empty(&self) -> bool

Implementations on Foreign Types

Source

impl IsEmpty for &str

Source

fn is_empty(&self) -> bool

Source

impl IsEmpty for &CStr

Source

fn is_empty(&self) -> bool

Source

impl IsEmpty for &Path

Source

fn is_empty(&self) -> bool

Source

impl IsEmpty for &PathBuf

Source

fn is_empty(&self) -> bool

Source

impl IsEmpty for str

Source

fn is_empty(&self) -> bool

Source

impl IsEmpty for CString

Source

fn is_empty(&self) -> bool

Source

impl IsEmpty for String

Source

fn is_empty(&self) -> bool

Source

impl IsEmpty for CStr

Source

fn is_empty(&self) -> bool

Source

impl IsEmpty for RangeFull

Source

fn is_empty(&self) -> bool

Source

impl IsEmpty for PathBuf

Source

fn is_empty(&self) -> bool

Source

impl<Idx> IsEmpty for RangeFrom<Idx>

Source

fn is_empty(&self) -> bool

Source

impl<Idx> IsEmpty for RangeTo<Idx>

Source

fn is_empty(&self) -> bool

Source

impl<Idx: PartialOrd> IsEmpty for Range<Idx>

Source

fn is_empty(&self) -> bool

Source

impl<Idx: PartialOrd> IsEmpty for RangeInclusive<Idx>

Source

fn is_empty(&self) -> bool

Source

impl<K, V> IsEmpty for BTreeMap<K, V>

Source

fn is_empty(&self) -> bool

Source

impl<K, V> IsEmpty for HashMap<K, V>

Source

fn is_empty(&self) -> bool

Source

impl<T> IsEmpty for &[T]

Source

fn is_empty(&self) -> bool

Source

impl<T> IsEmpty for [T]

Source

fn is_empty(&self) -> bool

Source

impl<T> IsEmpty for BinaryHeap<T>

Source

fn is_empty(&self) -> bool

Source

impl<T> IsEmpty for BTreeSet<T>

Source

fn is_empty(&self) -> bool

Source

impl<T> IsEmpty for LinkedList<T>

Source

fn is_empty(&self) -> bool

Source

impl<T> IsEmpty for VecDeque<T>

Source

fn is_empty(&self) -> bool

Source

impl<T> IsEmpty for Vec<T>

Source

fn is_empty(&self) -> bool

Source

impl<T> IsEmpty for HashSet<T>

Source

fn is_empty(&self) -> bool

Source

impl<T, const N: usize> IsEmpty for &[T; N]

Source

fn is_empty(&self) -> bool

Source

impl<T, const N: usize> IsEmpty for [T; N]

Source

fn is_empty(&self) -> bool

Source

impl<T: IsEmpty + ?Sized> IsEmpty for Box<T>

Available on non-crate feature nostd only.
Source

fn is_empty(&self) -> bool

Source

impl<T: IsEmpty + ?Sized> IsEmpty for Rc<T>

Available on non-crate feature nostd only.
Source

fn is_empty(&self) -> bool

Implementors