IsNAN

Trait IsNAN 

pub trait IsNAN {
    // Required method
    fn is_nan(&self) -> bool;
}
Trait defining instance method is_nan() : bool that indicates whether the implementing type instance has a value that is deemed to be “not a number” (as in so for f32::NAN f64::NAN).

Additional Implementations on Foreign Types

Built-in Types

If the feature "implement-IsNAN-for-built_ins" is defined (as it is by "default"), then this is also implemented for the following types:

Required Methods

fn is_nan(&self) -> bool

Implementations on Foreign Types

Source

impl IsNAN for f32

Source

fn is_nan(&self) -> bool

Source

impl IsNAN for f64

Source

fn is_nan(&self) -> bool

Source

impl<T: IsNAN + ?Sized> IsNAN for Box<T>

Available on non-crate feature nostd only.
Source

fn is_nan(&self) -> bool

Source

impl<T: IsNAN + ?Sized> IsNAN for Rc<T>

Available on non-crate feature nostd only.
Source

fn is_nan(&self) -> bool

Implementors