base_traits

Trait ToISize

pub trait ToISize {
    // Required method
    fn to_isize(&self) -> isize;
}
Trait defining instance method to_isize() : isize that provides a potentially expensive conversion into isize.

It is expected that the implementing type “is-a” isize in a logical manner.

Additional Implementations on Foreign Types

Built-in Types

If the feature "implement-ToISize-for-built_ins" is defined (as it is by "default"), then this is also implemented for the following type(s):

  • isize;
  • i8;
  • i16 - if architecture is 16+ bits;
  • i32 - if architecture is 32+ bits;
  • i64 - if architecture is 64+ bits;
  • i128 - if architecture is 128+ bits;
  • u16 - if architecture is 32+ bits;
  • u32 - if architecture is 64+ bits;
  • u64 - if architecture is 128+ bits;

Required Methods

fn to_isize(&self) -> isize

Implementations on Foreign Types

Source

impl ToISize for i8

Source

fn to_isize(&self) -> isize

Source

impl ToISize for i16

Source

fn to_isize(&self) -> isize

Source

impl ToISize for i32

Source

fn to_isize(&self) -> isize

Source

impl ToISize for isize

Source

fn to_isize(&self) -> isize

Source

impl ToISize for u8

Source

fn to_isize(&self) -> isize

Source

impl ToISize for u16

Source

fn to_isize(&self) -> isize

Source

impl<T: ToISize + ?Sized> ToISize for Box<T>

Source

fn to_isize(&self) -> isize

Source

impl<T: ToISize + ?Sized> ToISize for Rc<T>

Source

fn to_isize(&self) -> isize

Implementors