Crate base_traits

source ·

Traits

  • Trait defining instance method as_f64() : f64 that provides a cost-free conversion into f64.
  • Trait defining instance method as_str() : &str that allows a type to expose its contiguous character representation to client code.
  • Trait defining instance method is_default() : bool that allows a type instance to indicate whether it holds the “default” value.
  • Trait defining instance method is_empty() : bool that indicates whether the implementing type instance is logically empty.
  • Trait defining instance method is_zero() : bool that indicates whether the implementing type instance is numerically zero.
  • Trait defining instance method len() : usize that indicates whether the implementing type instance is logically empty.
  • Trait defining instance method to_f64() : f64 that provides a potentially expensive conversion into f64.
  • Trait defining class method zero() : T that indicates whether the implementing type instance is numerically zero.