base_traits

Trait AsISize

pub trait AsISize {
    // Required method
    fn as_isize(&self) -> isize;
}
Trait defining instance method as_isize() : isize that provides a cost-free conversion into isize.

It is expected that the implementing type “is-a” isize in a direct manner as well as in a logical manner.

Additional Implementations on Foreign Types

Built-in Types

If the feature "implement-AsISize-for-built_ins" is defined (as it is by "default"), then this is also implemented for the following type(s):

Required Methods

fn as_isize(&self) -> isize

Implementations on Foreign Types

Source

impl AsISize for isize

Source

fn as_isize(&self) -> isize

Source

impl<T: AsISize + ?Sized> AsISize for Box<T>

Source

fn as_isize(&self) -> isize

Source

impl<T: AsISize + ?Sized> AsISize for Rc<T>

Source

fn as_isize(&self) -> isize

Implementors