base_traits

Trait IsInfinity

pub trait IsInfinity {
    // Required method
    fn is_infinity(&self) -> bool;
}
Trait defining instance method is_infinity() : bool that indicates whether the implementing type instance is conceptually (or actually) infinite.

Additional Implementations on Foreign Types

Built-in Types

If the feature "implement-IsInfinity-for-built_ins" is defined (as it is by "default"), then this is also implemented for the following types:

Required Methods

fn is_infinity(&self) -> bool

Implementations on Foreign Types

Source

impl IsInfinity for f32

Source

impl IsInfinity for f64

Source

impl<T: IsInfinity + ?Sized> IsInfinity for Box<T>

Source

impl<T: IsInfinity + ?Sized> IsInfinity for Rc<T>

Implementors